@@ -28,8 +28,8 @@
 extern "C" {
 #endif
 
-#define LIBMSEED_VERSION "2.19"
-#define LIBMSEED_RELEASE "2017.053"
+#define LIBMSEED_VERSION "2.19.5"
+#define LIBMSEED_RELEASE "2017.283"
 
 /* C99 standard headers */
 #include <stdlib.h>
@@ -118,6 +118,8 @@ extern "C" {
   #include <inttypes.h>
 #endif
 
+extern int LM_SIZEOF_OFF_T;  /* Size of off_t data type determined at build time */
+
 #define MINRECLEN   128      /* Minimum Mini-SEED record length, 2^7 bytes */
                              /* Note: the SEED specification minimum is 256 */
 #define MAXRECLEN   1048576  /* Maximum Mini-SEED record length, 2^20 bytes */
